"""Tests for classname module"""

"""___Built-In Modules___"""
#import here

"""___Third-Party Modules___"""
import unittest

"""___NPL Modules___"""
#import here

"""___Authorship___"""
__author__ = "Pieter De Vis"
__created__ = "01/02/2021"
__maintainer__ = "Pieter De Vis"
__email__ = "pieter.de.vis@npl.co.uk"
__status__ = "Development"


class TestClassName(unittest.TestCase):
    def test_function1(self):
        pass

if __name__ == "__main__":
    unittest.main()
        